embassy-mcxa

Crates

git

Versions

mcx-a577

Flavors

AnyChannel

Struct AnyChannel 

pub struct AnyChannel { /* private fields */ }
Type-erased DMA channel peripheral.

This allows storing DMA channels in a uniform way regardless of their concrete type, useful for async transfer futures and runtime channel selection.

let anychannel: Peri<'static, AnyChannel> = p.DMA_CH0.into();
DmaChannel::new(anychannel);