pub struct TransferErrors(/* private fields */);Expand description
A collection of TransferError returned by any transfer.
Each error variant can be queried separately, or all errors can be iterated by using TransferErrors::into_iter.
Implementations
Sourceimpl TransferErrors
impl TransferErrors
Sourcepub fn has_destination_bus_err(&self) -> bool
pub fn has_destination_bus_err(&self) -> bool
Destination Bus Error
Sourcepub fn has_source_bus_err(&self) -> bool
pub fn has_source_bus_err(&self) -> bool
Source Bus Error
Sourcepub fn has_scatter_gather_configuration_err(&self) -> bool
pub fn has_scatter_gather_configuration_err(&self) -> bool
Indicates that TCDn_DLAST_SGA is not on a 32-byte boundary. This field is
checked at the beginning of a scatter/gather operation after major loop completion
if TCDn_CSR[ESG] is enabled.
Sourcepub fn has_nbytes_citer_configuration_err(&self) -> bool
pub fn has_nbytes_citer_configuration_err(&self) -> bool
This error indicates that one of the following has occurred:
TCDn_NBYTESis not a multiple ofTCDn_ATTR[SSIZE]andTCDn_ATTR[DSIZE]TCDn_CITER[CITER]is equal to zeroTCDn_CITER[ELINK]is not equal toTCDn_BITER[ELINK]
Sourcepub fn has_destination_offset_err(&self) -> bool
pub fn has_destination_offset_err(&self) -> bool
TCDn_DOFF is inconsistent with TCDn_ATTR[DSIZE].
Sourcepub fn has_destination_address_err(&self) -> bool
pub fn has_destination_address_err(&self) -> bool
TCDn_DADDR is inconsistent with TCDn_ATTR[DSIZE].
Sourcepub fn has_source_offset_err(&self) -> bool
pub fn has_source_offset_err(&self) -> bool
TCDn_SOFF is inconsistent with TCDn_ATTR[SSIZE].
Sourcepub fn has_source_address_err(&self) -> bool
pub fn has_source_address_err(&self) -> bool
TCDn_SADDR is inconsistent with TCDn_ATTR[SSIZE]