#[non_exhaustive]pub struct TransferOptions {
pub half_transfer_interrupt: bool,
pub complete_transfer_interrupt: bool,
pub priority: Priority,
}Expand description
DMA transfer options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.half_transfer_interrupt: boolEnable interrupt on half transfer complete.
complete_transfer_interrupt: boolEnable interrupt on transfer complete.
priority: PriorityTransfer priority
Implementations
Sourceimpl TransferOptions
impl TransferOptions
Sourcepub const NO_INTERRUPTS: Self
pub const NO_INTERRUPTS: Self
Short-hand to specify that no options should be configured.
Sourcepub const COMPLETE_INTERRUPT: Self
pub const COMPLETE_INTERRUPT: Self
Short-hand to specify that only the complete transfer interrupt should be triggered.